<?php
/**
 * Gentics Portal.Node PHP
 * Author & Copyright (c) by Gentics Software GmbH
 * sales@gentics.com
 * http://www.gentics.com
 * Licenses can be found in the LICENSE.txt file in the root-folder of this installation
 * You must not use this software without a valid license agreement.
 *
 * Abstract class for access to content repository
 */
abstract class ContentSource extends CComponent
{

    /**
     * If use personalization for current content source
     *
     * @var
     */
    public $usePersonalisation;

    /**
     * Array of fields which will be additionally request from Gentics Content Connector
     * and used in personalisation checking algorithm
     *
     * @var
     */
    public $personalisationFields = array();

    /**
     * Method which receive content path and return content
     *
     * @param string $path content path
     *
     * @return mixed
     */
    public abstract function getContent($path);

    public abstract function getStartPage($folderPath, $locale);

    /**
     * Get content file location
     *
     * @param string $path local path
     *
     * @return string
     *
     */
    public abstract function contentFile($path);

    /**
     * Return array of attributes which will be requested from API
     *
     * @abstract
     * @return array array of attributes
     */
    public abstract function getRequestedAttributes();

    /**
     * Check if file placed in $contentFolder folder. Prevent '../' attack.
     *
     * @param string $filePath relative file path
     * @param string $folder   in which file should placed
     *
     * @return bool
     */
    public static function fileAccessible($filePath, $folder)
    {
        if ($realPath = realpath($filePath)) {
            return strpos($realPath, realpath($folder)) === 0;
        }

        return false;
    }

    /**
     * Get repository api class
     *
     * @return RepositoryApi
     */
    public function getRepositoryApi()
    {
        return Yii::app()->repositoryApi;
    }
}
