<?php
    /**
     * Gentics Portal.Node PHP
     * Author & Copyright (c) by Gentics Software GmbH
     * sales@gentics.com
     * http://www.gentics.com
     * Licenses can be found in the LICENSE.txt file in the root-folder of this installation
     * You must not use this software without a valid license agreement.
     *
     * Comment controller class file.
     *
     * @author Vitalii Kovalchuk <vitaly.kovalchuk@oberig.com>
     */
class AdvancedSearchWidget extends BaseJuiWidget
{

    /**
     * @var string $useAutosuggest defines if Autosuggestion should be used for current widget
     */
    public $useAutosuggest = true;

    /**
     * @var string $uniqClassName system generated unique css ckass name
     */
    public $uniqClassName;

    /**
     * @var array $config contains required configuration for AdvancedSearchForm
     */
    public $config = array();

    /**
     * @var string $landingPage defines action for search form
     */
    public $landingPage = '';

    /**
     * Overrided autosuggest url
     *
     * @public string
     **/
    public $autosuggestUrl;

    /**
     * Default called method
     *
     * @return void
     */
    public function run()
    {
        $lang = Yii::app()->language;
        $this->uniqClassName = uniqid('simpleSearch');

        /*  if we did not configure landing page as widget param then take it from settings */
        if ($this->landingPage == '') {
            $this->landingPage = SearchModule::getLandingPage($lang);
        }
        $this->_loadConfig();

        $this->render('AdvancedSearchWidget', array('landingPage' => $this->landingPage));
    }

    /**
     * Loads configuration from module to class attribute
     *
     * @return void
     */
    private function _loadConfig()
    {
        $this->config['mimetype'] = Yii::app()->getModule('search')->mimetype;
        $this->config['whereToSearch'] = Yii::app()->getModule('search')->whereToSearch;
        $this->config['searchType'] = Yii::app()->getModule('search')->searchType;
        $this->config['urlLimiter'] = Yii::app()->getModule('search')->urlLimiter;

        foreach ($this->config as $type=>$config) {
            if (isset($config['options'])) {
                foreach ($config['options'] as $option=>$value) {
                    $this->config[$type]['options'][$option] = SearchModule::t($value);
                }
            }
        }
    }

    public function getSecureAutosuggestUrl()
    {
        if(empty($this->autosuggestUrl)) {
            return '';
        }
        $sm = Yii::app()->securityManager;
        return $sm->hashData($this->autosuggestUrl);
    }
}
