<?php
/**
 * Gentics Portal.Node PHP
 * Author & Copyright (c) by Gentics Software GmbH
 * sales@gentics.com
 * http://www.gentics.com
 * Licenses can be found in the LICENSE.txt file in the root-folder of this installation
 * You must not use this software without a valid license agreement.
 *
 * ImportController controller class file.
 */
class ImportController extends Controller
{
    /**
     * Sets filter for CRUD operations in this case
     * @return array action filters
     */
    public function filters()
    {
        return CMap::mergeArray(
            parent::filters(),
            array(
                'accessControl', // perform access control for CRUD operations
            )
        );
    }

    /**
     * Specifies the access control rules.
     * Allows access for admins only
     * @return array access control rules
     */
    public function accessRules()
    {
        return array(
            array('deny', // deny all users
                'actions' => array('delete'),
                'users' => array('*'),
            ),
            array('allow', // allow authenticated users to access all actions
                'roles'=>array('Admin'),
            ),
            array('deny'),
        );
    }
    /**
     * Method renders a row for the table comprising the import date
     * @return html markup with date
     */
    public function renderImportTableRow(&$importFile, $index, $csv_row){
        if(!$csv_row){
            return;
        }
        $user    = $importFile->getUserFromCsvRow($csv_row);
        $profile = $importFile->getProfileFromCsvRow($csv_row);

        if(isset($_POST['submit_validate'])||isset($_POST['submit_import'])){
            importFile::overrideExisted($user,$profile);
        }

        if(isset($_POST['submit_validate'])){

            if(!isset($importFile->valid)){
                $importFile->valid = true;
            }

            if(isset($_POST['enable_override'])){
                $user->setScenario('nameIsNotUniq');
            }

            if(!($user->getIsNewRecord() && !isset($_POST['enable_override']))){
                $importFile->valid = $user->validate($importFile->getFieldNames()) && $importFile->valid;

                if($profile){
                    $importFile->valid = $profile->validate($importFile->getFieldNames()) && $importFile->valid;
                }
            }

            if(!$importFile->valid){
                $importFile->assignError();
            }
        }//end submit_import || submit_validate

        if(isset($_POST['submit_import'])){
            $importFile->valid = (isset($_POST['valid'])&&$_POST['valid']==1)? true: false;

            if($importFile->valid){
                if($user->getIsNewRecord() || (!$user->getIsNewRecord() && isset($_POST['enable_override']))){

                    $user->save(false);
                    $user->justSaved = true;

                    if($profile){
                        $profile->user_id = $user->id;
                        $profile->save(false);
                    }
                }
            }
        }

        return $this->renderPartial('user.views.import._import_table_row',array(
            'importFile' => $importFile,
            'user' => $user,
            'profile' => $profile,
            'index' => $index
        ), true);

        unset($user);
        unset($profile);
    }

    public function actionIndex(){

        $importFile = new ImportFile;
        if(isset($_POST['csvImportFile_hashname'])){
            $importFile->file = $_POST['csvImportFile_realname'];
            $importFile->hashname = $_POST['csvImportFile_hashname'];
        }
        /*
         * File uploading block
         */
        if(isset($_POST['ImportFile'])){

            $importFile->attributes=$_POST['ImportFile'];
            $importFile->file = CUploadedFile::getInstance($importFile,'file');

            if($importFile->validate() && !empty($importFile->file)){
                $importFile->hashname = uniqid('import_').".csv";

                $destpath = $importFile->getPathToFile();
                $importFile->file->saveAs($destpath);

                $importFile->file = $importFile->file->getName();
            }
        }

        $this->render('index', array(
            'importFile'=>$importFile,
        ));
    }
}