<?php

/**
 * Widget for pooling questions. Show question and available answers.
 *
 **/
class PoolWidget extends BaseWidget
{
    /**
     * Unique question identification string
     *
     * @var string
     **/
    public $id;

    /**
     * Id of author of the question
     *
     * @var string
     **/
    public $author_id;
    /**
     * Question
     *
     * @var string
     **/
    public $question;

    /**
     * Array of answers with options.
     * Format: 'key1' => array(
     *               array(
     *               'order' => 1, //optional
     *               'text' => 'Yes I do',
     *              ),
     *          'key2' => array(
     *               'order' => 2, //optional
     *               'text' => 'No I dont',
     *              )
     *           )
     *
     * @var array
     **/
    public $answers;
    
    /**
     * If allowed to selectmultiply answers
     *
     * @var boolean
     **/
    public $multiply = false;

    /**
     * Defines a default page, where the user will be forwarded if he clicks the “save”-button (default: same page)
     *
     * @var string
     **/
    public $forwardTo;

    /**
     * Give the ability to hide/display a “show results”-link without giving an answer
     *
     * @var string
     **/
    public $resultsLink;

    /**
     * If show link to voting results without vouting
     *
     * @public boolean
     **/
    public $showResultsLink = false;
    /**
     * If single-answer-selection: don’t display a “save”-button; save on click on answer
     *
     * @var boolean
     **/
    public $dynamic;

    /**
     * Defines if anonymous answers can be given
     *
     * @var boolean
     **/
    public $allowAnonymous;

    /**
     * Array of variables and values, that should be added to the form and saved with the given answer
     *
     * @var array
     **/
    public $additionalFields = array();

    /**
     * Submit form via ajax
     *
     * @public string
     **/
    public $ajax;

    /**
     * If show widget for voted user
     *
     * @public boolean
     **/
    public $votedShow = true;

    /**
     * Here stored ResultsWidget options. They are used for ajax reloading
     *
     * @public string
     **/
    public $resultOptions;

    public function init()
    {
        if($this->forwardTo === null){
            $this->forwardTo = Yii::app()->request->requestUri;
        }
    }

    public function run()
    {
        if(!$this->votedShow && Yii::app()->getModule('vote')->isUserVoted($this->id)) {
            $this->render('PoolWidget_hidden');
            return;
        }
        //find question with answers by id
        $question = Question::model()->with('answers')->findByPk($this->id);
        //create or update question if needs
        if(!$question) {
            $question = new Question();
            $question->id = $this->id;
            $question->text = $this->question;
            $question->author_id = $this->author_id;
            if(!$question->save()){
                throw new Exception(print_r($question->getErrors(),true));
            }
        } elseif($question->text != $this->question || $question->author_id != $this->author_id) {
            $question->text = $this->question;
            $question->author_id = $this->author_id;
            $question->update(array('text', 'author_id'));
        }
        //create or update answers if needs
        $answerByKey = array();
        foreach ($question->answers as $answ) {
            $answerByKey[$answ->answer_key] = $answ;
        }
        $activeAnswers = array();
        foreach ($this->answers as $answerKey => $answer) {
            if(!is_string($answerKey)) {
                throw new Exception(VoteModule::t('Answer id should be string type. Answer: "{answer}". Id: {id}', array('{answer}' => $answer['text'], '{id}' => $answerKey)));
            }
            if(isset($answerByKey[$answerKey])) {
                $existedAnswer = $answerByKey[$answerKey];
                unset($answerByKey[$answerKey]);
                if($existedAnswer->active != 1 || $existedAnswer->order != $answer['order'] || $existedAnswer->text != $answer['text']) {
                    $existedAnswer->active = 1;
                    $existedAnswer->order = $answer['order'];
                    $existedAnswer->text = $answer['text'];
                    $existedAnswer->update(array('active', 'order', 'text'));
                }             
                $activeAnswers[] = $existedAnswer;
            } else {
                $newAnswer = new Answer();
                $newAnswer->question_id = $question->id;
                $newAnswer->answer_key = $answerKey;
                $newAnswer->order = $answer['order'];
                $newAnswer->text = $answer['text'];
                if(!$newAnswer->save()){
                    throw new Exception(print_r($newAnswer->getErrors(),true));
                }
                $activeAnswers[] = $newAnswer;
            }
        }
        //Make not used answers not active
        foreach ($answerByKey as $answer) {
            if ($answer->active != 0) {
                $answer->active = 0;
                $answer->update(array('active'));
            }
        }
        usort($activeAnswers, function($a, $b){ return $a->order - $b->order;});
        $answersData = array();
        foreach ($activeAnswers as $answ) {
            $answersData[$answ->id] = $answ->text;
        }
        $this->render('PoolWidget', array('question' => $question, 'answers' => $answersData));
    }

    public function getSecureResultOptions()
    {
        return Yii::app()->securityManager->hashData(serialize($this->resultOptions));
    }
}
